==> ibiz-model-8.1.0.317-sources.jar: net/ibizsys/model/dataentity/datamap/PSDEMapDataSetImpl.java <==
package net.ibizsys.model.dataentity.datamap;



public class PSDEMapDataSetImpl extends net.ibizsys.model.dataentity.datamap.PSDEMapObjectImpl implements net.ibizsys.model.dataentity.datamap.IPSDEMapDataSet{

	public final static String ATTR_GETDSTPSDEDATASET = "getDstPSDEDataSet";
	public final static String ATTR_GETMAPMODE = "mapMode";
	public final static String ATTR_GETMAPPARAMS = "mapParams";
	public final static String ATTR_GETSRCPSDEDATASET = "getSrcPSDEDataSet";
	private net.ibizsys.model.dataentity.ds.IPSDEDataSet dstpsdedataset;

	public net.ibizsys.model.dataentity.ds.IPSDEDataSet getDstPSDEDataSet(){
		if(this.dstpsdedataset != null) return this.dstpsdedataset;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDSTPSDEDATASET);
		if(value == null){
			return null;
		}
		net.ibizsys.model.dataentity.datamap.IPSDEMap ipsdemap = getParentPSModelObject(net.ibizsys.model.dataentity.datamap.IPSDEMap.class);
		this.dstpsdedataset = ipsdemap.getDstPSDEMust().getPSDEDataSet(value, false);
		return this.dstpsdedataset;
	}

	public net.ibizsys.model.dataentity.ds.IPSDEDataSet getDstPSDEDataSetMust(){
		net.ibizsys.model.dataentity.ds.IPSDEDataSet value = this.getDstPSDEDataSet();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定目标实体数据集合");}
		return value;
	}


	public java.lang.String getMapMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMAPMODE);
		if(value == null){
			return "DEFAULT";
		}
		return value.asText();
	}

	public com.fasterxml.jackson.databind.node.ObjectNode getMapParams(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMAPPARAMS);
		if(value == null){
			return null;
		}
		return (com.fasterxml.jackson.databind.node.ObjectNode)value;
	}
	private net.ibizsys.model.dataentity.ds.IPSDEDataSet srcpsdedataset;

	public net.ibizsys.model.dataentity.ds.IPSDEDataSet getSrcPSDEDataSet(){
		if(this.srcpsdedataset != null) return this.srcpsdedataset;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSRCPSDEDATASET);
		if(value == null){
			return null;
		}
		net.ibizsys.model.dataentity.IPSDataEntity ipsdataentity = getParentPSModelObject(net.ibizsys.model.dataentity.IPSDataEntity.class);
		this.srcpsdedataset = ipsdataentity.getPSDEDataSet(value, false);
		return this.srcpsdedataset;
	}

	public net.ibizsys.model.dataentity.ds.IPSDEDataSet getSrcPSDEDataSetMust(){
		net.ibizsys.model.dataentity.ds.IPSDEDataSet value = this.getSrcPSDEDataSet();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定源实体数据集合");}
		return value;
	}

}

==> ibiz-model-8.1.0.465-sources.jar: net/ibizsys/model/dataentity/datamap/PSDEMapDataSetImpl.java <==
package net.ibizsys.model.dataentity.datamap;



public class PSDEMapDataSetImpl extends net.ibizsys.model.dataentity.datamap.PSDEMapObjectImpl implements net.ibizsys.model.dataentity.datamap.IPSDEMapDataSet{

	public final static String ATTR_GETDSTPSDEDATASET = "getDstPSDEDataSet";
	public final static String ATTR_GETMAPMODE = "mapMode";
	public final static String ATTR_GETMAPPARAMS = "mapParams";
	public final static String ATTR_GETSRCPSDEDATASET = "getSrcPSDEDataSet";
	public final static String ATTR_ISENABLEDQCOND = "enableDQCond";
	private net.ibizsys.model.dataentity.ds.IPSDEDataSet dstpsdedataset;

	public net.ibizsys.model.dataentity.ds.IPSDEDataSet getDstPSDEDataSet(){
		if(this.dstpsdedataset != null) return this.dstpsdedataset;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDSTPSDEDATASET);
		if(value == null){
			return null;
		}
		net.ibizsys.model.dataentity.datamap.IPSDEMap ipsdemap = getParentPSModelObject(net.ibizsys.model.dataentity.datamap.IPSDEMap.class);
		this.dstpsdedataset = ipsdemap.getDstPSDEMust().getPSDEDataSet(value, false);
		return this.dstpsdedataset;
	}

	public net.ibizsys.model.dataentity.ds.IPSDEDataSet getDstPSDEDataSetMust(){
		net.ibizsys.model.dataentity.ds.IPSDEDataSet value = this.getDstPSDEDataSet();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定目标实体数据集合");}
		return value;
	}


	public java.lang.String getMapMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMAPMODE);
		if(value == null){
			return "DEFAULT";
		}
		return value.asText();
	}

	public com.fasterxml.jackson.databind.node.ObjectNode getMapParams(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMAPPARAMS);
		if(value == null){
			return null;
		}
		return (com.fasterxml.jackson.databind.node.ObjectNode)value;
	}
	private net.ibizsys.model.dataentity.ds.IPSDEDataSet srcpsdedataset;

	public net.ibizsys.model.dataentity.ds.IPSDEDataSet getSrcPSDEDataSet(){
		if(this.srcpsdedataset != null) return this.srcpsdedataset;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETSRCPSDEDATASET);
		if(value == null){
			return null;
		}
		net.ibizsys.model.dataentity.IPSDataEntity ipsdataentity = getParentPSModelObject(net.ibizsys.model.dataentity.IPSDataEntity.class);
		this.srcpsdedataset = ipsdataentity.getPSDEDataSet(value, false);
		return this.srcpsdedataset;
	}

	public net.ibizsys.model.dataentity.ds.IPSDEDataSet getSrcPSDEDataSetMust(){
		net.ibizsys.model.dataentity.ds.IPSDEDataSet value = this.getSrcPSDEDataSet();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定源实体数据集合");}
		return value;
	}


	public boolean isEnableDQCond(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISENABLEDQCOND);
		if(value == null){
			return false;
		}
		return value.asBoolean();
	}
}
